

AnalyticOpticalElement
=======================================

.. currentmodule:: poppy.poppy_core

.. autoclass:: AnalyticOpticalElement
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~AnalyticOpticalElement.display
      ~AnalyticOpticalElement.getPhasor
      ~AnalyticOpticalElement.sample
      ~AnalyticOpticalElement.toFITS

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: display
   .. automethod:: getPhasor
   .. automethod:: sample
   .. automethod:: toFITS

   
   